@@ -104,10 +104,12 @@ impl<R: Realigner> Variant for Mnv<R> {
         _: &AlignmentProperties,
         alt_variants: &[Box<dyn Realignable>],
     ) -> Result<Option<AlleleSupport>> {
-        if utils::contains_indel_op(&**read) {
+        if utils::contains_indel_op(&**read) || !alt_variants.is_empty() {
             // METHOD: reads containing indel operations should always be realigned,
             // as their support or non-support of the MNV might be an artifact
-            // of the aligner.
+            // of the aligner. Also, if we have alt alignments here, we need to
+            // realign as well since we need the multi-allelic case handling in the
+            // realigner.
             Ok(Some(self.realigner.borrow_mut().allele_support(
                 &**read,
                 [&self.locus].iter(),
